==> yta_stock_downloader-0.1.0-py3-none-any.whl: yta_stock_downloader/__init__.py <==
# from yta_stock_downloader.pixabay import Pixabay
# from yta_stock_downloader.pexels import Pexels


# __all__ = [
#     Pixabay,
#     Pexels
# ]



from yta_stock_downloader.pexels.image import get_first_pexels_image, download_first_pexels_image
from yta_stock_downloader.pexels.video import get_first_pexels_video, download_first_pexels_video, download_random_pexels_video
from yta_stock_downloader.pixabay.image import get_first_pixabay_image, download_first_pixabay_image
from yta_stock_downloader.pixabay.video import get_first_pixabay_video, download_first_pixabay_video, download_random_pixabay_video
from yta_stock_downloader.pixabay.dataclasses import PixabayImage, PixabayVideo
from yta_stock_downloader.pexels.dataclasses import PexelsImage, PexelsVideo
from yta_stock_downloader.enums import PexelsLocale
from yta_stock_downloader.validation import validate_query, validate_ids_to_ignore
from yta_general_utils.programming.output import Output
from yta_general_utils.file.enums import FileTypeX
from yta_general_utils.dataclasses import FileReturn
from typing import Union
from abc import ABC, abstractmethod
from typing import Union


class _StockDownloader(ABC):
    """
    Class to wrap the functionality related to
    downloading stock images and videos.

    This class must be inherited from the 
    specific classes that implement the 
    platform-specific functionality.
    """

    _ids_to_ignore: list[int]
    """
    The internal list of ids that must be ignored
    when trying to download a new one.
    """

    def __init__(
        self,
        do_ignore_ids: bool = False
    ):
        self._do_ignore_ids = do_ignore_ids

    @abstractmethod
    def download(
        self,
        query: str,
        ids_to_ignore: list[int] = [],
        output_filename: Union[str, None] = None
    ):
        """
        Download the first available image from the
        platform and stores it locally with the
        'output_filename' name provided.

        This instance will ignore previously downloaded
        images if 'do_ignore_ids' was passed as True,
        but you can also provide some ids within the
        'ids_to_ignore' parameter to ignore them.
        """
        pass

    @abstractmethod
    def reset(
        self
    ):
        """
        This method will empty the array that handles 
        the duplicated ids (if activated) to enable 
        downloading any image found again.
        """
        pass

class StockImageDownloader(_StockDownloader):
    """
    Class to download stock images from the
    different platforms available.
    
    This is a general image downloader which
    will choose by itself the platform from
    which obtain the images. If you need a
    platform-specific stock image downloader,
    use one of the specific classes.
    """

    def __init__(
        self,
        do_ignore_ids: bool = False
    ):
        self._do_ignore_ids = do_ignore_ids
        self._pexels_downloader = PexelsImageDownloader()
        self._pixabay_downloader = PixabayImageDownloader()

    def download(
        self,
        query: str,
        ids_to_ignore: list[int] = [],
        output_filename: Union[str, None] = None
    ) -> FileReturn:
        """
        Download an image from the first platform that
        has results according to the provided 'query'
        and stores it locally.
        """
        output_filename = Output.get_filename(output_filename, FileTypeX.IMAGE)

        image = self._pexels_downloader.download(
            query = query,
            ids_to_ignore = ids_to_ignore,
            output_filename = output_filename
        )

        if image is not None:
            return image
        
        image = self._pixabay_downloader.download(
            query = query,
            ids_to_ignore = ids_to_ignore,
            output_filename = output_filename
        )

        if image is not None:
            return image
        
        # TODO: Use another provider when available
        raise Exception('No results found with any of our providers.')

class StockVideoDownloader(_StockDownloader):
    """
    Class to download stock videos from the
    different platforms available.
    
    This is a general video downloader which
    will choose by itself the platform from
    which obtain the videos. If you need a
    platform-specific stock video downloader,
    use one of the specific classes.
    """

    def __init__(
        self,
        do_ignore_ids: bool = False
    ):
        self._do_ignore_ids = do_ignore_ids
        self._pexels_downloader = PexelsVideoDownloader()
        self._pixabay_downloader = PixabayVideoDownloader()

    def download(
        self,
        query: str,
        ids_to_ignore: list[int] = [],
        output_filename: Union[str, None] = None
    ) -> FileReturn:
        """
        Download a video from the first platform that
        has results according to the provided 'query'
        and stores it locally.
        """
        output_filename = Output.get_filename(output_filename, FileTypeX.VIDEO)

        video = self._pexels_downloader.download(
            query = query,
            ids_to_ignore = ids_to_ignore,
            output_filename = output_filename
        )

        if video is not None:
            return video
        
        video = self._pixabay_downloader.download(
            query = query,
            ids_to_ignore = ids_to_ignore,
            output_filename = output_filename
        )

        if video is not None:
            return video
        
        # TODO: Use another provider when available
        raise Exception('No results found with any of our providers.')

class PexelsImageDownloader(_StockDownloader):
    """
    Class to provide images from the Pexels platform.

    This class uses the Pexels API and our registered
    API key to obtain the results.

    See: https://www.pexels.com/
    """

    @staticmethod
    def get_first_image(
        query: str,
        locale: Union[PexelsLocale, str] = PexelsLocale.ES_ES,
        ids_to_ignore: list[int] = []
    ) -> Union[PexelsImage, None]:
        """
        Obtain the first available image from the Pexels
        provider for the given 'query' and 'locale' (if
        available).

        This method raises an Exception if no image 
        available.
        """
        validate_query(query)
        validate_ids_to_ignore(ids_to_ignore)
        locale = PexelsLocale.to_enum(locale)

        return get_first_pexels_image(
            query,
            locale,
            ids_to_ignore
        )
    
    @staticmethod
    def download(
        query: str,
        locale: Union[PexelsLocale, str] = PexelsLocale.ES_ES,
        ids_to_ignore: list[int] = [],
        output_filename: Union[str, None] = None
    ) -> Union[FileReturn, None]:
        """
        Download the first available image from the Pexels
        provider for the given 'query' and 'locale' (if
        available).

        This method raises an Exception if no image 
        available or if the download is not possible.
        """
        validate_query(query)
        validate_ids_to_ignore(ids_to_ignore)
        locale = PexelsLocale.to_enum(locale)

        return download_first_pexels_image(
            query,
            locale,
            ids_to_ignore,
            Output.get_filename(output_filename, FileTypeX.IMAGE)
        )

class PexelsVideoDownloader(_StockDownloader):
    """
    Class to provide videos from the Pexels platform.

    This class uses the Pexels API and our registered
    API key to obtain the results.

    See: https://www.pexels.com/
    """

    @staticmethod
    def get_first_video(
        query: str,
        locale: Union[PexelsLocale, str] = PexelsLocale.ES_ES,
        ids_to_ignore: list[int] = []
    ) -> Union[PexelsVideo, None]:
        """
        Obtain the first available video from the Pexels
        provider for the given 'query' and 'locale' (if
        available).
        
        This method raises an Exception if no video
        available or if the download is not possible.
        """
        validate_query(query)
        validate_ids_to_ignore(ids_to_ignore)
        locale = PexelsLocale.to_enum(locale)

        return get_first_pexels_video(
            query,
            locale,
            ids_to_ignore
        )

    @staticmethod
    def download(
        query: str,
        locale: Union[PexelsLocale, str] = PexelsLocale.ES_ES,
        ids_to_ignore: list[int] = [],
        output_filename: Union[str, None] = None
    ) -> Union[FileReturn, None]:
        """
        Download the first available video from the Pexels
        provided and the given 'query' and locale' (if
        existing) avoiding the ones in the 'ignore_ids' 
        list.

        This method raises an Exception if no video
        available to download or if the download is
        not possible.
        """
        validate_query(query)
        validate_ids_to_ignore(ids_to_ignore)
        locale = PexelsLocale.to_enum(locale)

        return download_first_pexels_video(
            query,
            locale,
            ids_to_ignore,
            Output.get_filename(output_filename, FileTypeX.IMAGE)
        )
    
    @staticmethod
    def download_random(
        query: str,
        locale: Union[PexelsLocale, str] = PexelsLocale.ES_ES,
        ids_to_ignore: list[int] = [],
        output_filename: Union[str, None] = None
    ) -> Union[FileReturn, None]:
        """
        Download a random video from the Pexels provided
        and the given 'query' and locale' (if existing)
        avoiding the ones in the 'ids_to_ignore' list.

        This method raises an Exception if no video
        available to download or if the download is
        not possible.
        """
        validate_query(query)
        validate_ids_to_ignore(ids_to_ignore)
        locale = PexelsLocale.to_enum(locale)

        return download_random_pexels_video(
            query,
            locale,
            ids_to_ignore,
            Output.get_filename(output_filename, FileTypeX.IMAGE)
        )

class PixabayImageDownloader(_StockDownloader):
    """
    Class to provide images and videos from the Pixabay
    platform.

    This class uses the Pixabay API and our registered
    API key to obtain the results.

    See: https://pixabay.com/
    """

    def get_first_image(
        query: str,
        ids_to_ignore: list[int] = []
    ) -> Union[PixabayImage, None]:
        """
        Obtain the first available image from the Pexels
        provider for the given 'query' (if available).

        This method raises an Exception if no image 
        available.
        """
        validate_query(query)
        validate_ids_to_ignore(ids_to_ignore)

        return get_first_pixabay_image(
            query,
            ids_to_ignore
        )
    
    @staticmethod
    def download(
        query: str,
        ids_to_ignore: list[int] = [],
        output_filename: Union[str, None] = None
    ) -> Union[FileReturn, None]:
        """
        Download the first available image from the Pexels
        provider for the given 'query' (if available).

        This method raises an Exception if no image 
        available or if the download is not possible.
        """
        validate_query(query)
        validate_ids_to_ignore(ids_to_ignore)

        return download_first_pixabay_image(
            query,
            ids_to_ignore,
            Output.get_filename(output_filename, FileTypeX.IMAGE)
        )
    
class PixabayVideoDownloader(_StockDownloader):
    """
    Class to provide videos from the Pixabay platform.

    This class uses the Pixabay API and our registered
    API key to obtain the results.

    See: https://pixabay.com/
    """

    @staticmethod
    def get_first_video(
        query: str,
        ids_to_ignore: list[int] = []
    ) -> Union[PixabayVideo, None]:
        """
        Obtain the first available video from the Pixabay
        provider for the given 'query' (if available).
        
        This method raises an Exception if no video
        available or if the download is not possible.
        """
        validate_query(query)
        validate_ids_to_ignore(ids_to_ignore)

        return get_first_pixabay_video(
            query,
            ids_to_ignore
        )

    @staticmethod
    def download(
        query: str,
        ids_to_ignore: list[int] = [],
        output_filename: Union[str, None] = None
    ) -> Union[FileReturn, None]:
        """
        Download the first available video from the Pexels
        provided and the given 'query' (if existing)
        avoiding the ones in the 'ids_to_ignore' list.

        This method raises an Exception if no video
        available to download or if the download is
        not possible.
        """
        validate_query(query)
        validate_ids_to_ignore(ids_to_ignore)

        return download_first_pixabay_video(
            query,
            ids_to_ignore,
            Output.get_filename(output_filename, FileTypeX.IMAGE)
        )
    
    @staticmethod
    def download_random(
        query: str,
        ids_to_ignore: list[int] = [],
        output_filename: Union[str, None] = None
    ) -> Union[FileReturn, None]:
        """
        Download a random video from the Pexels provided
        and the given 'query' (if existing) avoiding the
        ones in the 'ids_to_ignore' list.

        This method raises an Exception if no video
        available to download or if the download is
        not possible.
        """
        validate_query(query)
        validate_ids_to_ignore(ids_to_ignore)

        return download_random_pixabay_video(
            query,
            ids_to_ignore,
            Output.get_filename(output_filename, FileTypeX.IMAGE)
        )

# TODO: I should implement a way of using pagination
# and look for next page results if not found in the
# current page and a behaviour like that

==> yta_stock_downloader-0.1.2-py3-none-any.whl: yta_stock_downloader/__init__.py <==
from yta_stock_downloader.pexels.image import get_first_pexels_image, download_first_pexels_image, download_random_pexels_image
from yta_stock_downloader.pexels.video import get_first_pexels_video, download_first_pexels_video, download_random_pexels_video
from yta_stock_downloader.pixabay.image import get_first_pixabay_image, download_first_pixabay_image, download_random_pixabay_image
from yta_stock_downloader.pixabay.video import get_first_pixabay_video, download_first_pixabay_video, download_random_pixabay_video
from yta_stock_downloader.pixabay.dataclasses import PixabayImage, PixabayVideo
from yta_stock_downloader.pexels.dataclasses import PexelsImage, PexelsVideo
from yta_stock_downloader.pexels.enums import PexelsLocale
from yta_stock_downloader.validation import validate_query, validate_ids_to_ignore
from yta_general_utils.programming.output import Output
from yta_general_utils.file.enums import FileTypeX
from yta_general_utils.dataclasses import FileReturn
from typing import Union
from abc import ABC, abstractmethod
from typing import Union


class _StockDownloader(ABC):
    """
    Class to wrap the functionality related to
    downloading stock images and videos.

    This class must be inherited from the 
    specific classes that implement the 
    platform-specific functionality.
    """

    _ids_to_ignore: list[int]
    """
    The internal list of ids that must be ignored
    when trying to download a new one.
    """

    def __init__(
        self,
        do_ignore_ids: bool = False
    ):
        self._do_ignore_ids = do_ignore_ids

    @abstractmethod
    def download(
        self,
        query: str,
        ids_to_ignore: list[int] = [],
        output_filename: Union[str, None] = None
    ):
        """
        Download the first available image from the
        platform and stores it locally with the
        'output_filename' name provided.
        """
        pass

    @abstractmethod
    def download_random(
        self,
        query: str,
        ids_to_ignore: list[int] = [],
        output_filename: Union[str, None] = None
    ):
        """
        Download a random available image from the
        platform and stores it locally with the
        'output_filename' name provided.
        """
        pass

    @abstractmethod
    def reset(
        self
    ):
        """
        This method will empty the array that handles 
        the duplicated ids (if activated) to enable 
        downloading any image found again.
        """
        pass

class StockImageDownloader(_StockDownloader):
    """
    Class to download stock images from the
    different platforms available.
    
    This is a general image downloader which
    will choose by itself the platform from
    which obtain the images. If you need a
    platform-specific stock image downloader,
    use one of the specific classes.
    """

    def __init__(
        self,
        do_ignore_ids: bool = False
    ):
        self._do_ignore_ids = do_ignore_ids
        self._pexels_downloader = PexelsImageDownloader()
        self._pixabay_downloader = PixabayImageDownloader()

    def download(
        self,
        query: str,
        ids_to_ignore: list[int] = [],
        output_filename: Union[str, None] = None
    ) -> FileReturn:
        """
        Download an image from the first platform that
        has results according to the provided 'query'
        and stores it locally.
        """
        output_filename = Output.get_filename(output_filename, FileTypeX.IMAGE)

        image = self._pexels_downloader.download(
            query = query,
            ids_to_ignore = ids_to_ignore,
            output_filename = output_filename
        )

        if image is not None:
            return image
        
        image = self._pixabay_downloader.download(
            query = query,
            ids_to_ignore = ids_to_ignore,
            output_filename = output_filename
        )

        if image is not None:
            return image
        
        # TODO: Use another provider when available
        raise Exception('No results found with any of our providers.')
    
    def download_random(
        self,
        query: str,
        ids_to_ignore: list[int] = [],
        output_filename: Union[str, None] = None
    ) -> FileReturn:
        """
        Download a random image from the first platform
        that has results according to the provided 'query'
        and stores it locally.
        """
        output_filename = Output.get_filename(output_filename, FileTypeX.IMAGE)

        image = self._pexels_downloader.download_random(
            query = query,
            ids_to_ignore = ids_to_ignore,
            output_filename = output_filename
        )

        if image is not None:
            return image
        
        image = self._pixabay_downloader.download_random(
            query = query,
            ids_to_ignore = ids_to_ignore,
            output_filename = output_filename
        )

        if image is not None:
            return image
        
        # TODO: Use another provider when available
        raise Exception('No results found with any of our providers.')

class StockVideoDownloader(_StockDownloader):
    """
    Class to download stock videos from the
    different platforms available.
    
    This is a general video downloader which
    will choose by itself the platform from
    which obtain the videos. If you need a
    platform-specific stock video downloader,
    use one of the specific classes.
    """

    def __init__(
        self,
        do_ignore_ids: bool = False
    ):
        self._do_ignore_ids = do_ignore_ids
        self._pexels_downloader = PexelsVideoDownloader()
        self._pixabay_downloader = PixabayVideoDownloader()

    def download(
        self,
        query: str,
        ids_to_ignore: list[int] = [],
        output_filename: Union[str, None] = None
    ) -> FileReturn:
        """
        Download a video from the first platform that
        has results according to the provided 'query'
        and stores it locally.
        """
        output_filename = Output.get_filename(output_filename, FileTypeX.VIDEO)

        video = self._pexels_downloader.download(
            query = query,
            ids_to_ignore = ids_to_ignore,
            output_filename = output_filename
        )

        if video is not None:
            return video
        
        video = self._pixabay_downloader.download(
            query = query,
            ids_to_ignore = ids_to_ignore,
            output_filename = output_filename
        )

        if video is not None:
            return video
        
        # TODO: Use another provider when available
        raise Exception('No results found with any of our providers.')
    
    def download_random(
        self,
        query: str,
        ids_to_ignore: list[int] = [],
        output_filename: Union[str, None] = None
    ) -> FileReturn:
        """
        Download a random video from the first platform
        that has results according to the provided 'query'
        and stores it locally.
        """
        output_filename = Output.get_filename(output_filename, FileTypeX.VIDEO)

        video = self._pexels_downloader.download_random(
            query = query,
            ids_to_ignore = ids_to_ignore,
            output_filename = output_filename
        )

        if video is not None:
            return video
        
        video = self._pixabay_downloader.download_random(
            query = query,
            ids_to_ignore = ids_to_ignore,
            output_filename = output_filename
        )

        if video is not None:
            return video
        
        # TODO: Use another provider when available
        raise Exception('No results found with any of our providers.')

class PexelsImageDownloader(_StockDownloader):
    """
    Class to provide images from the Pexels platform.

    This class uses the Pexels API and our registered
    API key to obtain the results.

    See: https://www.pexels.com/
    """

    @staticmethod
    def get_first_image(
        query: str,
        locale: Union[PexelsLocale, str] = PexelsLocale.ES_ES,
        ids_to_ignore: list[int] = []
    ) -> Union[PexelsImage, None]:
        """
        Obtain the first available image from the Pexels
        provider for the given 'query' and 'locale' (if
        available).

        This method raises an Exception if no image 
        available.
        """
        validate_query(query)
        validate_ids_to_ignore(ids_to_ignore)
        locale = PexelsLocale.to_enum(locale)

        return get_first_pexels_image(
            query,
            locale,
            ids_to_ignore
        )
    
    @staticmethod
    def download(
        query: str,
        locale: Union[PexelsLocale, str] = PexelsLocale.ES_ES,
        ids_to_ignore: list[int] = [],
        output_filename: Union[str, None] = None
    ) -> Union[FileReturn, None]:
        """
        Download the first available image from the Pexels
        provider for the given 'query' and 'locale' (if
        available).

        This method raises an Exception if no image 
        available or if the download is not possible.
        """
        validate_query(query)
        validate_ids_to_ignore(ids_to_ignore)
        locale = PexelsLocale.to_enum(locale)

        return download_first_pexels_image(
            query,
            locale,
            ids_to_ignore,
            Output.get_filename(output_filename, FileTypeX.IMAGE)
        )
    
    @staticmethod
    def download_random(
        query: str,
        locale: Union[PexelsLocale, str] = PexelsLocale.ES_ES,
        ids_to_ignore: list[int] = [],
        output_filename: Union[str, None] = None
    ) -> Union[FileReturn, None]:
        """
        Download a random available image from the Pexels
        provider for the given 'query' and 'locale' (if
        available).

        This method raises an Exception if no image 
        available or if the download is not possible.
        """
        validate_query(query)
        validate_ids_to_ignore(ids_to_ignore)
        locale = PexelsLocale.to_enum(locale)

        return download_random_pexels_image(
            query,
            locale,
            ids_to_ignore,
            Output.get_filename(output_filename, FileTypeX.IMAGE)
        )

class PexelsVideoDownloader(_StockDownloader):
    """
    Class to provide videos from the Pexels platform.

    This class uses the Pexels API and our registered
    API key to obtain the results.

    See: https://www.pexels.com/
    """

    @staticmethod
    def get_first_video(
        query: str,
        locale: Union[PexelsLocale, str] = PexelsLocale.ES_ES,
        ids_to_ignore: list[int] = []
    ) -> Union[PexelsVideo, None]:
        """
        Obtain the first available video from the Pexels
        provider for the given 'query' and 'locale' (if
        available).
        
        This method raises an Exception if no video
        available or if the download is not possible.
        """
        validate_query(query)
        validate_ids_to_ignore(ids_to_ignore)
        locale = PexelsLocale.to_enum(locale)

        return get_first_pexels_video(
            query,
            locale,
            ids_to_ignore
        )

    @staticmethod
    def download(
        query: str,
        locale: Union[PexelsLocale, str] = PexelsLocale.ES_ES,
        ids_to_ignore: list[int] = [],
        output_filename: Union[str, None] = None
    ) -> Union[FileReturn, None]:
        """
        Download the first available video from the Pexels
        provided and the given 'query' and locale' (if
        existing) avoiding the ones in the 'ignore_ids' 
        list.

        This method raises an Exception if no video
        available to download or if the download is
        not possible.
        """
        validate_query(query)
        validate_ids_to_ignore(ids_to_ignore)
        locale = PexelsLocale.to_enum(locale)

        return download_first_pexels_video(
            query,
            locale,
            ids_to_ignore,
            Output.get_filename(output_filename, FileTypeX.IMAGE)
        )
    
    @staticmethod
    def download_random(
        query: str,
        locale: Union[PexelsLocale, str] = PexelsLocale.ES_ES,
        ids_to_ignore: list[int] = [],
        output_filename: Union[str, None] = None
    ) -> Union[FileReturn, None]:
        """
        Download a random video from the Pexels provided
        and the given 'query' and locale' (if existing)
        avoiding the ones in the 'ids_to_ignore' list.

        This method raises an Exception if no video
        available to download or if the download is
        not possible.
        """
        validate_query(query)
        validate_ids_to_ignore(ids_to_ignore)
        locale = PexelsLocale.to_enum(locale)

        return download_random_pexels_video(
            query,
            locale,
            ids_to_ignore,
            Output.get_filename(output_filename, FileTypeX.IMAGE)
        )

class PixabayImageDownloader(_StockDownloader):
    """
    Class to provide images and videos from the Pixabay
    platform.

    This class uses the Pixabay API and our registered
    API key to obtain the results.

    See: https://pixabay.com/
    """

    def get_first_image(
        query: str,
        ids_to_ignore: list[int] = []
    ) -> Union[PixabayImage, None]:
        """
        Obtain the first available image from the Pexels
        provider for the given 'query' (if available).

        This method raises an Exception if no image 
        available.
        """
        validate_query(query)
        validate_ids_to_ignore(ids_to_ignore)

        return get_first_pixabay_image(
            query,
            ids_to_ignore
        )
    
    @staticmethod
    def download(
        query: str,
        ids_to_ignore: list[int] = [],
        output_filename: Union[str, None] = None
    ) -> Union[FileReturn, None]:
        """
        Download the first available image from the Pexels
        provider for the given 'query' (if available).

        This method raises an Exception if no image 
        available or if the download is not possible.
        """
        validate_query(query)
        validate_ids_to_ignore(ids_to_ignore)

        return download_first_pixabay_image(
            query,
            ids_to_ignore,
            Output.get_filename(output_filename, FileTypeX.IMAGE)
        )
    
    @staticmethod
    def download_random(
        query: str,
        ids_to_ignore: list[int] = [],
        output_filename: Union[str, None] = None
    ) -> Union[FileReturn, None]:
        """
        Download a random available image from the Pexels
        provider for the given 'query' (if available).

        This method raises an Exception if no image 
        available or if the download is not possible.
        """
        validate_query(query)
        validate_ids_to_ignore(ids_to_ignore)

        return download_random_pixabay_image(
            query,
            ids_to_ignore,
            Output.get_filename(output_filename, FileTypeX.IMAGE)
        )
    
class PixabayVideoDownloader(_StockDownloader):
    """
    Class to provide videos from the Pixabay platform.

    This class uses the Pixabay API and our registered
    API key to obtain the results.

    See: https://pixabay.com/
    """

    @staticmethod
    def get_first_video(
        query: str,
        ids_to_ignore: list[int] = []
    ) -> Union[PixabayVideo, None]:
        """
        Obtain the first available video from the Pixabay
        provider for the given 'query' (if available).
        
        This method raises an Exception if no video
        available or if the download is not possible.
        """
        validate_query(query)
        validate_ids_to_ignore(ids_to_ignore)

        return get_first_pixabay_video(
            query,
            ids_to_ignore
        )

    @staticmethod
    def download(
        query: str,
        ids_to_ignore: list[int] = [],
        output_filename: Union[str, None] = None
    ) -> Union[FileReturn, None]:
        """
        Download the first available video from the Pexels
        provided and the given 'query' (if existing)
        avoiding the ones in the 'ids_to_ignore' list.

        This method raises an Exception if no video
        available to download or if the download is
        not possible.
        """
        validate_query(query)
        validate_ids_to_ignore(ids_to_ignore)

        return download_first_pixabay_video(
            query,
            ids_to_ignore,
            Output.get_filename(output_filename, FileTypeX.IMAGE)
        )
    
    @staticmethod
    def download_random(
        query: str,
        ids_to_ignore: list[int] = [],
        output_filename: Union[str, None] = None
    ) -> Union[FileReturn, None]:
        """
        Download a random video from the Pexels provided
        and the given 'query' (if existing) avoiding the
        ones in the 'ids_to_ignore' list.

        This method raises an Exception if no video
        available to download or if the download is
        not possible.
        """
        validate_query(query)
        validate_ids_to_ignore(ids_to_ignore)

        return download_random_pixabay_video(
            query,
            ids_to_ignore,
            Output.get_filename(output_filename, FileTypeX.IMAGE)
        )

# TODO: I should implement a way of using pagination
# and look for next page results if not found in the
# current page and a behaviour like that
